@@ -1,4 +1,5 @@
 import inspect
+import hashlib
 import logging
 import os
 
@@ -12,15 +13,12 @@ logger = logging.getLogger(__name__)
 
 
 def parse_distutils_request(request):
-    """Parse the `request.raw_post_data` and update the request POST and FILES
+    """Parse the `request.body` and update the request POST and FILES
     attributes .
 
     """
 
-    try:
-        sep = request.raw_post_data.splitlines()[1]
-    except:
-        raise ValueError('Invalid post data')
+    sep = request.body.splitlines()[1]
 
     request.POST = QueryDict('', mutable=True)
     try:
@@ -28,7 +26,7 @@ def parse_distutils_request(request):
     except Exception:
         pass
 
-    for part in filter(lambda e: e.strip(), request.raw_post_data.split(sep)):
+    for part in filter(lambda e: e.strip(), request.body.split(sep)):
         try:
             header, content = part.lstrip().split('\n', 1)
         except Exception:
@@ -108,3 +106,14 @@ def delete_files(sender, **kwargs):
                 logger.exception(
                     'Error when trying to delete file %s of package %s:' % (
                         instance.pk, fieldfile.path))
+
+
+def md5_hash_file(fh):
+    """Return the md5 hash of the given file-object"""
+    md5 = hashlib.md5()
+    while True:
+        data = fh.read(8192)
+        if not data:
+            break
+        md5.update(data)
+    return md5.hexdigest()
