@@ -1,7 +1,11 @@
 import logging
+from wsgiref.util import FileWrapper
 
+from django.conf import settings
 from django.contrib.auth.decorators import login_required, permission_required
 from django.core.exceptions import ObjectDoesNotExist
+from django.core.urlresolvers import reverse
+from django.db.models import Q
 from django.http import Http404, HttpResponse, HttpResponseBadRequest
 from django.http import HttpResponseForbidden
 from django.shortcuts import redirect
@@ -10,15 +14,16 @@ from django.views.decorators.csrf import csrf_exempt
 from django.views.generic.detail import DetailView
 from django.views.generic.list import ListView
 
-from localshop.http import HttpResponseUnauthorized
-from localshop.views import LoginRequiredMixin, PermissionRequiredMixin
 from localshop.apps.packages import forms
 from localshop.apps.packages import models
 from localshop.apps.packages.pypi import get_package_data
+from localshop.apps.packages.pypi import get_search_names
 from localshop.apps.packages.signals import release_file_notfound
 from localshop.apps.packages.utils import parse_distutils_request
 from localshop.apps.permissions.utils import credentials_required
 from localshop.apps.permissions.utils import split_auth, authenticate_user
+from localshop.http import HttpResponseUnauthorized
+from localshop.views import LoginRequiredMixin, PermissionRequiredMixin
 
 logger = logging.getLogger(__name__)
 
@@ -79,16 +84,27 @@ class SimpleDetail(DetailView):
         return super(SimpleDetail, self).dispatch(request, *args, **kwargs)
 
     def get(self, request, slug, version=None):
+        condition = Q()
+        for name in get_search_names(slug):
+            condition |= Q(name__iexact=name)
+
         try:
-            package = models.Package.objects.get(name__iexact=slug)
+            package = models.Package.objects.get(condition)
         except ObjectDoesNotExist:
             package = get_package_data(slug)
 
         if package is None:
             raise Http404
 
+        # Redirect if slug is not an exact match
+        if slug != package.name:
+            url = reverse('packages-simple:simple_detail', kwargs={
+                'slug': package.name, 'version': version
+            })
+            return redirect(url)
+
         releases = package.releases
-        if version:
+        if version and not package.is_local:
             releases = releases.filter(version=version)
 
             # Perhaps this version is new, refresh data
@@ -125,6 +141,7 @@ class Detail(LoginRequiredMixin, PermissionRequiredMixin, DetailView):
     def get_context_data(self, *args, **kwargs):
         context = super(Detail, self).get_context_data(*args, **kwargs)
         context['release'] = self.object.last_release
+        context['pypi_url'] = settings.LOCALSHOP_PYPI_URL
         return context
 
 
@@ -141,24 +158,34 @@ def refresh(request, name):
 
 @credentials_required
 def download_file(request, name, pk, filename):
-    """Redirect the client to the pypi hosted file if the file is not
-    mirror'ed yet (and isn't a local package).  Otherwise serve the file.
-
     """
+    If the requested file is not already cached locally from a previous
+    download it will be fetched from PyPi for local storage and the client will
+    be redirected to PyPi, unless the LOCALSHOP_ISOLATED variable is set to
+    True, in wich case the file will be served to the client after it is
+    downloaded.
+    """
+
     release_file = models.ReleaseFile.objects.get(pk=pk)
     if not release_file.distribution:
         logger.info("Queueing %s for mirroring", release_file.url)
         release_file_notfound.send(sender=release_file.__class__,
                                    release_file=release_file)
-        return redirect(release_file.url)
+        if not settings.LOCALSHOP_ISOLATED:
+            logger.debug("Redirecting user to pypi")
+            return redirect(release_file.url)
+        else:
+            release_file = models.ReleaseFile.objects.get(pk=pk)
 
     # TODO: Use sendfile if enabled
-    response = HttpResponse(release_file.distribution.file,
+    response = HttpResponse(
+        FileWrapper(release_file.distribution.file),
         content_type='application/force-download')
     response['Content-Disposition'] = 'attachment; filename=%s' % (
         release_file.filename)
-    if release_file.distribution.file.size:
-        response["Content-Length"] = release_file.distribution.file.size
+    size = release_file.distribution.file.size
+    if size:
+        response["Content-Length"] = size
     return response
 
 
