@@ -1,5 +1,5 @@
-from django.conf.urls.defaults import patterns
-from django.conf.urls.defaults import url
+from django.conf.urls import patterns, url
+
 from localshop.apps.permissions import views
 
 
@@ -20,6 +20,8 @@ urlpatterns = patterns('',
         name='credential_deactivate'),
     url(r'^credentials/(?P<access_key>[a-f0-9]+)/secret', views.secret_key,
         name='credential_secret'),
+    url(r'^credentials/(?P<access_key>[a-f0-9]+)/edit', views.CredentialUpdateView.as_view(),
+        name='credential_edit'),
     url(r'^credentials/(?P<access_key>[a-f0-9]+)/delete', views.CredentialDeleteView.as_view(),
         name='credential_delete'),
 )
