@@ -1,7 +1,8 @@
 import re
 from django.conf import settings
-from django.conf.urls.defaults import patterns, include, url
+from django.conf.urls import patterns, include, url
 from django.contrib import admin
+from django.views.generic.base import RedirectView
 
 from localshop.apps.packages.xmlrpc import handle_request
 
@@ -29,8 +30,8 @@ urlpatterns = patterns('',
     url(r'^permissions/',
         include('localshop.apps.permissions.urls', namespace='permissions')),
 
-    url(r'^accounts/signup/', 'django.views.generic.simple.redirect_to',
-        {'url': '/'}),
+    url(r'^accounts/signup/', RedirectView.as_view(url="/")),
+
     url(r'^accounts/', include('userena.urls')),
 
     url(r'^admin/', include(admin.site.urls)),
